package com.mdd.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mdd.admin.LikeAdminThreadLocal;
import com.mdd.admin.service.IClientGoodsService;
import com.mdd.admin.validate.ClientGoodsCreateValidate;
import com.mdd.admin.validate.ClientGoodsSearchValidate;
import com.mdd.admin.validate.ClientGoodsUpdateValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.vo.ClientGoodsDetailVo;
import com.mdd.admin.vo.ClientGoodsListedVo;
import com.mdd.common.core.PageResult;
import com.mdd.common.entity.ClientGoods;
import com.mdd.common.mapper.ClientGoodsMapper;
import com.mdd.common.util.TimeUtils;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

@Service
public class ClientGoodsServiceImpl implements IClientGoodsService {
   @Resource
   ClientGoodsMapper clientGoodsMapper;

   public PageResult<ClientGoodsListedVo> list(PageValidate pageValidate, ClientGoodsSearchValidate searchValidate) {
      Integer page = pageValidate.getPageNo();
      Integer limit = pageValidate.getPageSize();
      Integer adminId = LikeAdminThreadLocal.getAdminId();
      QueryWrapper<ClientGoods> queryWrapper = new QueryWrapper();
      queryWrapper.orderByAsc("sort");
      queryWrapper.eq("user_id", adminId);
      this.clientGoodsMapper.setSearch(queryWrapper, searchValidate, new String[]{"like:name:str", "=:domain:str", "=:templateId@template_id:int"});
      IPage<ClientGoods> iPage = this.clientGoodsMapper.selectPage(new Page((long)page, (long)limit), queryWrapper);
      List<ClientGoodsListedVo> list = new LinkedList();
      Iterator var9 = iPage.getRecords().iterator();

      while(var9.hasNext()) {
         ClientGoods item = (ClientGoods)var9.next();
         ClientGoodsListedVo vo = new ClientGoodsListedVo();
         BeanUtils.copyProperties(item, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(item.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(item.getUpdateTime()));
         list.add(vo);
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   public ClientGoodsDetailVo detail(Integer id) {
      ClientGoods model = (ClientGoods)this.clientGoodsMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("goods_id", id)).last("limit 1"));
      Assert.notNull(model, "数据不存在");
      ClientGoodsDetailVo vo = new ClientGoodsDetailVo();
      BeanUtils.copyProperties(model, vo);
      return vo;
   }

   public void add(ClientGoodsCreateValidate createValidate) {
      Integer adminId = LikeAdminThreadLocal.getAdminId();
      ClientGoods model = new ClientGoods();
      model.setDomain(createValidate.getDomain());
      model.setTemplateId(createValidate.getTemplateId());
      model.setType(createValidate.getType());
      model.setName(createValidate.getName());
      model.setProfile(createValidate.getProfile());
      model.setImages(createValidate.getImages());
      model.setStorage(createValidate.getStorage());
      model.setConfig(createValidate.getConfig());
      model.setSort(createValidate.getSort());
      model.setUserId(adminId);
      model.setCreateTime(System.currentTimeMillis() / 1000L);
      model.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.clientGoodsMapper.insert(model);
   }

   public void edit(ClientGoodsUpdateValidate updateValidate) {
      ClientGoods model = (ClientGoods)this.clientGoodsMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("goods_id", updateValidate.getGoodsId())).last("limit 1"));
      Assert.notNull(model, "数据不存在!");
      model.setDomain(updateValidate.getDomain());
      model.setType(updateValidate.getType());
      model.setName(updateValidate.getName());
      model.setProfile(updateValidate.getProfile());
      model.setImages(updateValidate.getImages());
      model.setStorage(updateValidate.getStorage());
      model.setConfig(updateValidate.getConfig());
      model.setSort(updateValidate.getSort());
      model.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.clientGoodsMapper.updateById(model);
   }

   public void del(Integer id) {
      ClientGoods model = (ClientGoods)this.clientGoodsMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("goods_id", id)).last("limit 1"));
      Assert.notNull(model, "数据不存在!");
      this.clientGoodsMapper.delete((Wrapper)(new QueryWrapper()).eq("goods_id", id));
   }
}
